"use client"
import Link from 'next/link';
import { useRouter } from 'next/navigation';
import React, { useState } from 'react';

const BASE_URL = 'http://localhost:8000/user-img/user-images/';

const Sidebar = ({ path, userId, userImage }) => {
  const router = useRouter();
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const [isLoggingOut, setIsLoggingOut] = useState(false);
  const [imageError, setImageError] = useState(false);

  // Logout handler function with loading state
  const handleLogout = async () => {
    try {
      setIsLoggingOut(true);
      localStorage.removeItem('userData');
      localStorage.removeItem('token');
      localStorage.clear();
      
      await new Promise(resolve => setTimeout(resolve, 300));
      router.push('/');
    } catch (error) {
      console.error('Logout error:', error);
      setIsLoggingOut(false);
    }
  };

  // Get profile image URL with fallback handling
  const getProfileImageUrl = () => {
    if (!userImage || imageError) {
      return '/dasboard-profile.png'; // Fallback image
    }
    return `${BASE_URL}${userImage}`;
  };

  const handleImageError = () => {
    setImageError(true);
  };

  const links = [
    {
      title: "Dashboard",
      image: "dashboard",
      href: `/dashboard/${userId}`
    },
    {
      title: "Account Settings",
      image: "person",
      href: `/account-settings`
    },
    {
      title: "My Properties",
      image: "profile",
      href: `/my-properties`
    },
    {
      title: "Add New Property",
      image: "add",
      href: `/add-property`
    },
    {
      title: "My Enquiry",
      image: "message",
      href: `/my-enquiry`
    },
    {
      title: "Purchase History",
      image: "rupee",
      href: `/purchase-history`
    },
    {
      title: "Favorites",
      image: "heart",
      href: `/favourites`
    },
    {
      title: "Review",
      image: "star",
      href: `/review`
    },
    {
      title: "Logout",
      image: "logout",
      href: "#"
    }
  ];

  return (
    <>
      {isLoggingOut && (
        <div className="fixed inset-0 bg-black bg-opacity-50 z-50 flex items-center justify-center">
          <div className="bg-white p-4 rounded-lg flex flex-col items-center">
            <div className="w-8 h-8 border-4 border-gray-300 border-t-secondary rounded-full animate-spin mb-2"></div>
            <p className="text-gray-800 font-medium">Logging out...</p>
          </div>
        </div>
      )}

      <div className='bg-[#343434] relative rounded-lg text-white flex flex-col gap-2 w-full max-w-[278px] pt-24 pb-12 mx-auto'>
        <button
          onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
          className='lg:hidden absolute top-4 left-4 z-10 text-white focus:outline-none'
          disabled={isLoggingOut}
        >
          <svg
            xmlns="http://www.w3.org/2000/svg"
            className="h-6 w-6"
            fill="none"
            viewBox="0 0 24 24"
            stroke="currentColor"
          >
            <path
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={2}
              d="M4 6h16M4 12h16M4 18h16"
            />
          </svg>
        </button>

        {/* Profile Image with error handling */}
        <img
          src={getProfileImageUrl()}
          alt="Profile"
          className='absolute top-[-55px] left-1/2 transform -translate-x-1/2 w-[110px] h-[110px] object-cover rounded-full lg:left-20 lg:transform-none'
          onError={handleImageError}
        />

        <div className={`
          flex-col gap-2
          ${isMobileMenuOpen 
            ? 'fixed inset-0 bg-[#343434] z-50 overflow-y-auto pt-24' 
            : 'hidden lg:flex'}
        `}>
          {isMobileMenuOpen && (
            <button
              onClick={() => setIsMobileMenuOpen(false)}
              className='absolute top-4 right-4 text-white lg:hidden'
              disabled={isLoggingOut}
            >
              <svg
                xmlns="http://www.w3.org/2000/svg"
                className="h-6 w-6"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  strokeWidth={2}
                  d="M6 18L18 6M6 6l12 12"
                />
              </svg>
            </button>
          )}

          {links.map((item, index) => (
            <React.Fragment key={item.title}>
              {index !== 0 && <div className="h-[1px] bg-white opacity-20"></div>}
              {item.title === "Logout" ? (
                <button
                  className={`
                    flex gap-4 font-semibold px-2 py-1 w-full
                    ${path === item.href ? 'text-secondary' : 'text-white'}
                    hover:bg-[#4a4a4a] transition-colors duration-200
                    ${isLoggingOut ? 'opacity-50 cursor-not-allowed' : ''}
                  `}
                  onClick={() => {
                    if (!isLoggingOut) {
                      setIsMobileMenuOpen(false);
                      handleLogout();
                    }
                  }}
                  disabled={isLoggingOut}
                >
                  <img
                    src={`/dashboard/${item.image}.svg`}
                    alt=""
                    className='w-6'
                  />
                  <p>{item.title}</p>
                </button>
              ) : (
                <Link
                  className={`
                    flex gap-4 font-semibold px-2 py-1
                    ${path === item.href ? 'text-secondary' : 'text-white'}
                    hover:bg-[#4a4a4a] transition-colors duration-200
                    ${isLoggingOut ? 'pointer-events-none opacity-50' : ''}
                  `}
                  href={item.href}
                  onClick={() => setIsMobileMenuOpen(false)}
                  tabIndex={isLoggingOut ? -1 : 0}
                >
                  <img
                    src={`/dashboard/${item.image}.svg`}
                    alt=""
                    className='w-6'
                  />
                  <p>{item.title}</p>
                </Link>
              )}
            </React.Fragment>
          ))}
        </div>
      </div>
    </>
  );
};

export default Sidebar;